/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     | Website:  https://openfoam.org
    \\  /    A nd           | Copyright (C) 2019 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::ParticleResponseTime

Description
    Function object which generates a lagrangian field containing the
    particle response time.

    Example usage:
    \verbatim
    ParticleResponseTime1
    {
        type        particleResponseTime;
    }
    \endverbatim

SourceFiles
    ParticleResponseTime.C

\*---------------------------------------------------------------------------*/

#ifndef ParticleResponseTime_H
#define ParticleResponseTime_H

#include "CloudFunctionObject.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                    Class ParticleResponseTime Declaration
\*---------------------------------------------------------------------------*/

template<class CloudType>
class ParticleResponseTime
:
    public CloudFunctionObject<CloudType>
{
protected:

    // Protected Member Functions

        //- Write post-processing info
        virtual void write();



public:

    //- Runtime type information
    TypeName("particleResponseTime");


    // Constructors

        //- Construct from dictionary
        ParticleResponseTime
        (
            const dictionary& dict,
            CloudType& owner,
            const word& modelName
        );

        //- Construct copy
        ParticleResponseTime(const ParticleResponseTime<CloudType>& ppm);

        //- Construct and return a clone
        virtual autoPtr<CloudFunctionObject<CloudType>> clone() const
        {
            return autoPtr<CloudFunctionObject<CloudType>>
            (
                new ParticleResponseTime<CloudType>(*this)
            );
        }


    //- Destructor
    virtual ~ParticleResponseTime();

};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#ifdef NoRepository
    #include "ParticleResponseTime.C"
#endif

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
